Coverage report

# Coverage report: 82%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 711 | 125 | 0 | 82%
/home/delusionalinsanity/bbrepos/matyan/src/matyan/__init__.py | 7 | 0 | 0 | 100%
/home/delusionalinsanity/bbrepos/matyan/src/matyan/auto_correct.py | 19 | 0 | 0 | 100%
/home/delusionalinsanity/bbrepos/matyan/src/matyan/config.py | 19 | 0 | 0 | 100%
/home/delusionalinsanity/bbrepos/matyan/src/matyan/constants.py | 6 | 0 | 0 | 100%
/home/delusionalinsanity/bbrepos/matyan/src/matyan/fetchers/__init__.py | 5 | 2 | 0 | 60%
/home/delusionalinsanity/bbrepos/matyan/src/matyan/fetchers/base.py | 28 | 8 | 0 | 71%
/home/delusionalinsanity/bbrepos/matyan/src/matyan/fetchers/jira.py | 25 | 11 | 0 | 56%
/home/delusionalinsanity/bbrepos/matyan/src/matyan/helpers.py | 7 | 0 | 0 | 100%
/home/delusionalinsanity/bbrepos/matyan/src/matyan/labels.py | 32 | 0 | 0 | 100%
/home/delusionalinsanity/bbrepos/matyan/src/matyan/patterns.py | 16 | 0 | 0 | 100%
/home/delusionalinsanity/bbrepos/matyan/src/matyan/registry.py | 23 | 2 | 0 | 91%
/home/delusionalinsanity/bbrepos/matyan/src/matyan/renderers/__init__.py | 3 | 0 | 0 | 100%
/home/delusionalinsanity/bbrepos/matyan/src/matyan/renderers/base.py | 83 | 15 | 0 | 82%
/home/delusionalinsanity/bbrepos/matyan/src/matyan/renderers/markdown.py | 27 | 1 | 0 | 96%
/home/delusionalinsanity/bbrepos/matyan/src/matyan/renderers/rest.py | 22 | 1 | 0 | 95%
/home/delusionalinsanity/bbrepos/matyan/src/matyan/utils.py | 389 | 85 | 0 | 78%

No items found using the specified filter.